# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/executor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import annotations_pb2 as eolymp_dot_annotations_dot_annotations__pb2
from eolymp.executor import task_pb2 as eolymp_dot_executor_dot_task__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/executor/executor.proto',
  package='eolymp.executor',
  syntax='proto3',
  serialized_options=b'Z7github.com/eolymp/contracts/go/eolymp/executor;executor',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65olymp/executor/executor.proto\x12\x0f\x65olymp.executor\x1a$eolymp/annotations/annotations.proto\x1a\x1a\x65olymp/executor/task.proto\"6\n\x0f\x43reateTaskInput\x12#\n\x04task\x18\x01 \x01(\x0b\x32\x15.eolymp.executor.Task\"\x12\n\x10\x43reateTaskOutput2\x95\x01\n\x08\x45xecutor\x12\x88\x01\n\nCreateTask\x12 .eolymp.executor.CreateTaskInput\x1a!.eolymp.executor.CreateTaskOutput\"5\x82\xd3\xe4\x93\x02/\"*/twirp/eolymp.executor.Executor/CreateTask:\x01*B9Z7github.com/eolymp/contracts/go/eolymp/executor;executorb\x06proto3'
  ,
  dependencies=[eolymp_dot_annotations_dot_annotations__pb2.DESCRIPTOR,eolymp_dot_executor_dot_task__pb2.DESCRIPTOR,])




_CREATETASKINPUT = _descriptor.Descriptor(
  name='CreateTaskInput',
  full_name='eolymp.executor.CreateTaskInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task', full_name='eolymp.executor.CreateTaskInput.task', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=171,
)


_CREATETASKOUTPUT = _descriptor.Descriptor(
  name='CreateTaskOutput',
  full_name='eolymp.executor.CreateTaskOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=173,
  serialized_end=191,
)

_CREATETASKINPUT.fields_by_name['task'].message_type = eolymp_dot_executor_dot_task__pb2._TASK
DESCRIPTOR.message_types_by_name['CreateTaskInput'] = _CREATETASKINPUT
DESCRIPTOR.message_types_by_name['CreateTaskOutput'] = _CREATETASKOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateTaskInput = _reflection.GeneratedProtocolMessageType('CreateTaskInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATETASKINPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.CreateTaskInput)
  })
_sym_db.RegisterMessage(CreateTaskInput)

CreateTaskOutput = _reflection.GeneratedProtocolMessageType('CreateTaskOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATETASKOUTPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.CreateTaskOutput)
  })
_sym_db.RegisterMessage(CreateTaskOutput)


DESCRIPTOR._options = None

_EXECUTOR = _descriptor.ServiceDescriptor(
  name='Executor',
  full_name='eolymp.executor.Executor',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=194,
  serialized_end=343,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateTask',
    full_name='eolymp.executor.Executor.CreateTask',
    index=0,
    containing_service=None,
    input_type=_CREATETASKINPUT,
    output_type=_CREATETASKOUTPUT,
    serialized_options=b'\202\323\344\223\002/\"*/twirp/eolymp.executor.Executor/CreateTask:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXECUTOR)

DESCRIPTOR.services_by_name['Executor'] = _EXECUTOR

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/python-proto-http for more details.
"""Generated protocol buffer code."""

from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class PlaygroundClient:
    def __init__(self, transport):
        self.transport = transport

    def CreateRun(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.playground.Playground/CreateRun",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.playground.CreateRunOutput"),
            **kwargs,
        )

    def DescribeRun(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.playground.Playground/DescribeRun",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.playground.DescribeRunOutput"),
            **kwargs,
        )

